==> hexalate_1.0.3.orig.tar.bz2: hexalate-1.0.3/translations/hexalate_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <location filename="../src/board.cpp" line="45"/>
        <source>Question</source>
        <translation>Vraag</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="45"/>
        <source>Abort current game?</source>
        <translation>Huidig spel afbreken?</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../src/locale_dialog.cpp" line="50"/>
        <source>Select application language:</source>
        <translation>Selekteer Taal:</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="53"/>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Systeem Taal&gt;</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="183"/>
        <source>Note</source>
        <translation>Aantekening</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="183"/>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Herstart AUB dit programma om de verandering van de taal door te voeren.</translation>
    </message>
</context>
<context>
    <name>Puzzle</name>
    <message>
        <location filename="../src/puzzle.cpp" line="162"/>
        <source>Success</source>
        <translation>Succes</translation>
    </message>
    <message>
        <location filename="../src/puzzle.cpp" line="204"/>
        <source>Sorry</source>
        <translation>Sorry</translation>
    </message>
    <message>
        <location filename="../src/puzzle.cpp" line="204"/>
        <source>Unable to load previous game. Starting a new game.</source>
        <translation>Kan huidige spel onmogelijk laden. Begin een nieuw spel.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/window.cpp" line="33"/>
        <location filename="../src/window.cpp" line="74"/>
        <source>Hexalate</source>
        <translation>Hexalate</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="40"/>
        <source>&amp;Game</source>
        <translation>&amp;Spel</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="41"/>
        <source>&amp;New</source>
        <translation>&amp;Nieuw</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="41"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="43"/>
        <source>&amp;Quit</source>
        <translation>&amp;Einde</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="43"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="45"/>
        <source>&amp;Settings</source>
        <translation>&amp;Instellingen</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="46"/>
        <source>Application &amp;Language...</source>
        <translation>Programma &amp;Taal...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="48"/>
        <source>&amp;Help</source>
        <translation>&amp;Help</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="49"/>
        <source>&amp;About</source>
        <translation>&amp;Over</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="50"/>
        <source>About &amp;Qt</source>
        <translation>Over &amp;Qt</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="73"/>
        <source>About Hexalate</source>
        <translation>Over Hexalate</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="75"/>
        <source>A color matching game</source>
        <translation>Een kleuren combinatiespel</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="76"/>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>Auteursrecht &amp;copie; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="77"/>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Uitgebracht omder de &lt;a href=%1&gt;GPL 3&lt;/a&gt; licensie</translation>
    </message>
</context>
</TS>

==> hexalate-1.2.5.tar.bz2: hexalate-1.2.5/translations/hexalate_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <source>Question</source>
        <translation>Vraag</translation>
    </message>
    <message>
        <source>Abort current game?</source>
        <translation>Huidig spel afbreken?</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Kies de programmataal:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;System Language&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Opmerking</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Herstart het programma om de taalwijziging toe te passen.</translation>
    </message>
</context>
<context>
    <name>Puzzle</name>
    <message>
        <source>Success</source>
        <translation>Voltooid</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Sorry</translation>
    </message>
    <message>
        <source>Unable to load previous game. Starting a new game.</source>
        <translation>Het vorige spel kan niet worden geladen - start een nieuw spel.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Hexalate</source>
        <translation>Hexalate</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Spel</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nieuw</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Afsluiten</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>In&amp;stellingen</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Programmataa&amp;l…</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hulp</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Over</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Over &amp;Qt</translation>
    </message>
    <message>
        <source>About Hexalate</source>
        <translation>Over Hexalate</translation>
    </message>
    <message>
        <source>A color matching game</source>
        <translation>Een kleurenkoppelspel</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Uitgebracht onder de &lt;a href=%1&gt;GPL 3&lt;/a&gt;-licentie</translation>
    </message>
</context>
</TS>
